# SPDX-FileCopyrightText: Copyright (c) 2020 Bryan Siepert for Adafruit Industries
#
# SPDX-License-Identifier: MIT
import time
import busio
from adafruit_lsm6ds.lsm6dsox import LSM6DSOX

# GPIO numbers
SDA0 = 0
SCL0 = 1
SDA1 = 2
SCL1 = 3

# Print GPIO Info
print("SDA0: " +str(SDA0))
print("SCL0: " +str(SCL0))

print("SDA1: " +str(SDA1))
print("SCL1: " +str(SCL1))


# Setup i2c buses
i2c0 = busio.I2C(SCL0, SDA0)
i2c1 = busio.I2C(SCL1, SDA1)

# Get sensor data from both devices using LSM6DSOX library
sensor0 = LSM6DSOX(i2c0)
sensor1 = LSM6DSOX(i2c1)

# Return a string that displays xyz acceleration data and xyz int acceleration values
def get_accel(sensor):
    accel = "Acceleration X:%.2f, Y: %.2f, Z: %.2f m/s^2" % (sensor.acceleration)
    xyz = list(sensor.acceleration)
    x = xyz[0]
    y = xyz[1]
    z = xyz[2]
    return [accel, x, y, z]

# Return a string that displays xyz gyroscope data and xyz int rotation values
def get_gyro(sensor):
    gyro = "Gyro X:%.2f, Y: %.2f, Z: %.2f radians/s" % (sensor.gyro)
    xyz = list(sensor.gyro)
    x = xyz[0]
    y = xyz[1]
    z = xyz[2]
    return [gyro, x, y, z]

while True:
    # Get Accelerations and Rotations
    accel0 = get_accel(sensor0)
    gyro0 = get_gyro(sensor0)
    accel1 = get_accel(sensor1)
    gyro1 = get_gyro(sensor1)
    
    # Print Acceleration and Gyroscope Results to Terminal
    print(" i2c0 ")
    print(accel0[0])
    print(gyro0[0])
    print(" i2c1 ")
    print(accel1[0])
    print(gyro1[0])
    print("")
            
    time.sleep(0.5)
