# SPDX-FileCopyrightText: Copyright (c) 2020 Bryan Siepert for Adafruit Industries
#
# SPDX-License-Identifier: MIT
import time
import matplotlib.pyplot as plt 
import busio
from adafruit_lsm6ds.lsm6dsox import LSM6DSOX

# GPIO numbers
SDA1 = 2
SCL1 = 3

# Setup i2c bus
i2c1 = busio.I2C(SCL1, SDA1)

# Get sensor data using LSM6DSOX library
s1 = LSM6DSOX(i2c1)

# Graph Variables
start_time= time.time()
t = 0
xlist = []
ylist = []
zlist = []
tlist = []

def get_accel(sensor):
    accel = "Acceleration X:%.2f, Y: %.2f, Z: %.2f m/s^2" % (sensor.acceleration)
    return accel

def get_x(sensor):
    xyz = list(sensor.acceleration)
    x = xyz[0]
    return x

def get_y(sensor):
    xyz = list(sensor.acceleration)
    y = xyz[1]
    return y

def get_z(sensor):
    xyz = list(sensor.acceleration)
    z = xyz[2]
    return z

def get_gyro(sensor):
    gyro = "Gyro X:%.2f, Y: %.2f, Z: %.2f radians/s" % (sensor.gyro)
    return gyro

while (time.time()-start_time < 20):
    
    # get data
    t = t + 1
    x = get_x(s1)
    y = get_y(s1)
    z = get_z(s1)
    
    # Add data to list
    xlist.append(x)
    ylist.append(y)
    zlist.append(z)
    tlist.append(t)
    

# line points 
x = xlist
y = ylist
z = zlist
t = tlist

# plotting the line 1 points  
plt.plot(t, x, label = "x") 
  
# plotting the line 2 points  
plt.plot(t, y, label = "y")

# plotting the line 2 points  
plt.plot(t, z, label = "z") 
  
# naming the x axis 
plt.xlabel('Time') 
# naming the y axis 
plt.ylabel('Acceleration') 
# giving a title to my graph 
plt.title('XYZ Acceleration Over Time') 
  
# show a legend on the plot 
plt.legend() 
  
# function to show the plot 
plt.show() 
