import time
import matplotlib.pyplot as plt 
import busio
from adafruit_lsm6ds.lsm6dsox import LSM6DSOX

# GPIO numbers
SDA0 = 0
SCL0 = 1
SDA1 = 2
SCL1 = 3

# Setup i2c bus
i2c0 = busio.I2C(SCL0, SDA0)
i2c1 = busio.I2C(SCL1, SDA1)

# Get sensor data using LSM6DSOX library
s0 = LSM6DSOX(i2c0)
s1 = LSM6DSOX(i2c1)

# time variables
start_time= time.time()
pause_time1 = time.time()
pause_time0 = time.time()
wait_time = 0.5

# acceleration variables
amax = 20

# Moves are one of -1 (NONE), 0 (UP), 1(LEFT), 2 (RIGHT), or 3 (DOWN))
U = 0
L = 1
R = 2
D = 3
N = -1

# Return a string that displays xyz acceleration data
def get_accel(sensor):
	accel = "Acceleration X:%.2f, Y: %.2f, Z: %.2f m/s^2" % (sensor.acceleration)
	return accel

# Return an int for x acceleration
def get_x(sensor):
	xyz = list(sensor.acceleration)
	x = xyz[0]
	return x

# Return an int for y acceleration
def get_y(sensor):
	xyz = list(sensor.acceleration)
	y = xyz[1]
	return y

# Return an int for z acceleration
def get_z(sensor):
	xyz = list(sensor.acceleration)
	z = xyz[2]
	return z

# Return a string that displays xyz gyroscope data
def get_gyro(sensor):
	gyro = "Gyro X:%.2f, Y: %.2f, Z: %.2f radians/s" % (sensor.gyro)
	return gyro

# return a list of averaged acceleration [x, y, z] for most recent xyz acceleration 
def get_aves(sensor):
	xav = 0
	yav = 0
	zav = 0
	for x in range(30):
		# get data
		x = get_x(sensor)
		y = get_y(sensor)
		z = get_z(sensor)
		
		# add new data to total
		xav = xav + x
		yav = yav + y
		zav = zav + z

	# divide total by number of samples
	xav = xav/30
	yav = yav/30
	zav = zav/30
	return [xav, yav, zav]
	
# return the current time relative to beginning of while loop
def get_time():
	t = time.time()-start_time
	return t
	
# returns true if we can signal next move
def ready_move(sensor):
	if sensor==s1:
		return time.time()-pause_time1 > wait_time
	else:
		return time.time()-pause_time0 > wait_time

# return number corresponding to direction of movement for right hand
def get_rmove(x, z):
	if x > amax: 
		return D
	elif x < -amax:
		return U
	elif z > amax:
		return L
	elif z < -amax:
		return R
	else:
		return N
		
# return number corresponding to direction of movement for left hand
def get_lmove(x, z):
	if x > amax: 
		return U
	elif x < -amax:
		return D
	elif z > amax:
		return R
	elif z < -amax:
		return L
	else:
		return N
		
		
# prints move and hand, returns nothing
def print_move(move, hand):
	if hand=="R":
		if move==U:
			print("R UP")
		if move==L:
			print("R LEFT")
		if move==R:
			print("R RIGHT")
		if move==D:
			print("R DOWN")
	if hand=="L":
		if move==U:
			print("L UP")
		if move==L:
			print("L LEFT")
		if move==R:
			print("L RIGHT")
		if move==D:
			print("L DOWN")
	
	
while (get_time() < 40):
	# get data for left hand = s0
	xyz0 = get_aves(s0)
	x0 = xyz0[0]
	z0 = xyz0[2]
	# get data for right hand = s1
	xyz1 = get_aves(s1)
	x1 = xyz1[0]
	z1 = xyz1[2]
	
	# determine move for sensor0
	if ready_move(s0): # if delay period is over
		move = get_lmove(x0, z0)
		if move!=-1: # a move has occurred
			pause_time0 = time.time() # set start of delay 
			print_move(move, "L")
	
	# determine move for sensor1		
	if ready_move(s1):	
		move = get_rmove(x1, z1)
		if move!=-1: # a move has occurred
			pause_time1 = time.time() # set start of delay 
			print_move(move, "R")
