"""
Constants used for game screen design for Music Motion
"""

# Whether to show on PiTFT screen or not (Monitor)
piTFT = False

# Color constants in RGB format
WHITE = 255, 255, 255
BLACK = 0, 0, 0
RED = 255, 0, 0
GREEN = 0, 255, 0
BLUE = 0, 0, 255

main_color = GREEN # Active arrow color
left_color = BLUE
right_color = RED

# Screen dimensions
width = 320 if piTFT else 600 # Set to 320 if PiTFT
height = width*3 // 4 # 240 if PiTFT

# Constants relative to screen size to help position different items
half_w = width // 2
half_h = height // 2
quarter_w = width // 4
quarter_h = height // 4
eighth_w = width // 8
eighth_h = height // 8

arrow_length = eighth_w # Length of arrow on main game screen
queue_arrow_length = arrow_length // 2

# Game aspect colors
b_color = BLACK # Background color
t_color = WHITE # Text color

# Positions of home screen text
title_pos = (half_w,quarter_h)
start_pos = (eighth_w,7*eighth_h)
quit_pos = (7*eighth_w,7*eighth_h)
select_song_pos = (half_w,half_h)
prev_pos = (eighth_w,5*eighth_h)
next_pos = (7*eighth_w,5*eighth_h)
curr_song_pos = (half_w,5*eighth_h)
left_pos = (quarter_w, eighth_h)
right_pos = (3*quarter_w, eighth_h)

"""
Returns list of start and end points for an arrow.
Arrow originates from pos x, y and is length arrow_size in direction listed.
Direction is one of 0 (UP), 1 (LEFT), 2 (RIGHT), or 3 (DOWN).
"""
def create_arrow_pos(x, y, arrow_size, direction):
    start = (x, y)
    end = (x, y)
    if direction == 0: # UP
        end = (x, y-arrow_size)
    if direction == 1: # LEFT
        end = (x-arrow_size, y)
    if direction == 2: # RIGHT
        end = (x+arrow_size, y)
    if direction == 3: # DOWN
        end = (x, y+arrow_size)
    return [start, end]

# Positions of arrows. List of first entry start and second entry end.
l_up_pos = create_arrow_pos(quarter_w, half_h, arrow_length, 0)
l_left_pos = create_arrow_pos(quarter_w, half_h, arrow_length, 1)
l_right_pos = create_arrow_pos(quarter_w, half_h, arrow_length, 2)
l_down_pos = create_arrow_pos(quarter_w, half_h, arrow_length, 3)

r_up_pos = create_arrow_pos(3*quarter_w, half_h, arrow_length, 0)
r_left_pos = create_arrow_pos(3*quarter_w, half_h, arrow_length, 1)
r_right_pos = create_arrow_pos(3*quarter_w, half_h, arrow_length, 2)
r_down_pos = create_arrow_pos(3*quarter_w, half_h, arrow_length, 3)
