"""
The Song class
"""
import multiprocessing # to play music as background process
from constants import * # for game design variables
from movement import Movement

class Song:
    """
    Initializer for a song.
    Parameters:
    title - string of song title (ex. "Senorita")
    fileTitle - string of music file (ex. "senorita.mp3")
    bpm - int of beats per minute (ex. 120)
    offset - float of how many seconds to skip into the song (ex. 8.0)
    """
    def __init__(self, title, fileTitle, bpm, offset = 0.0):
        self.title = title
        self.fileTitle = fileTitle
        self.bpm = bpm
        self.offset = offset
        self.moves = []
        self.moveNumber = 0

    """
    Increments to the next movement in the sequence if it exists (True). Otherwise
    stops song (False).
    """
    def incrementMove(self):
        self.moveNumber += 1
        if self.moveNumber > len(self.moves) - 3: # -3 for song padding
            return False
        return True

    """
    Returns the current move.
    """
    def currMove(self):
        return self.moves[self.moveNumber]

    """
    Returns the next move.
    """
    def nextMove(self):
        return self.moves[self.moveNumber+1]

    """
    Returns the next next move.
    """
    def nextNextMove(self):
        return self.moves[self.moveNumber+2]

    """
    Adds a single movement to the move set for the song
    """
    def addMove(self, left = -1, right = -1):
        self.moves.append(Movement(left,right))

    """
    Adds movements to the move set for the song. Movement list consists of
    tuples where the first entry is the left move and the second entry is the
    right move.
    """
    def addMoves(self, lst):
        for (left, right) in lst:
            self.addMove(left,right)

    """
    Pads the song with some empty moves.
    """
    def pad(self, num = 3):
        for i in range(num):
            self.addMove()

    """
    Resets the song so it can be played again.
    """
    def reset(self):
        self.moveNumber = 0
